@@ -7,16 +7,18 @@
 """SerialHub backend widget & support classes"""
 
 from __future__ import absolute_import
-#from __future__ import print_function
-from typing import Sequence, Mapping, Any, ByteString, Optional  # , BinaryIO, IO
 
-import ipywidgets #from ipywidgets import DOMWidget, register
-import traitlets
-#from traitlets.traitlets import Integer #from traitlets import Unicode, Int, Bool, Complex, Enum
+from typing import Sequence, Mapping, Any, ByteString, Optional, Callable  # , BinaryIO, IO
+
+import ipywidgets #eg: DOMWidget, register
+import traitlets #eg: Integer, Unicode, Bool, Complex, Enum
+
 from ._frontend import module_name, module_version
+from .serialio import SerialIOProvider
+
 
 @ipywidgets.register
-class SerialHubWidget(ipywidgets.DOMWidget):
+class SerialHubWidget(ipywidgets.DOMWidget, SerialIOProvider):
     """\
     SerialHubWidget class inherits ipywidgets.DOMWidget
         Model: SerialHubModel, View: SerialHubView
@@ -90,24 +92,11 @@ class SerialHubWidget(ipywidgets.DOMWidget):
     ).tag(sync=True)
 
     def __init__(self, *args, **kwargs):
-        #TODO: Allow request & serial options to be passed at construction
+        #FUTURE: Allow request & serial options to be passed at construction
         ipywidgets.DOMWidget.__init__(self, *args, **kwargs)
-        self._cb_recv = None
+        self._cb_recv: Optional[Callable[[ByteString], None]] = None
         self.on_msg(self.msg_custom)
 
-    def on_recv(self, cb_recv):
-        """Set callback for received buffers of serial data"""
-        self._cb_recv = cb_recv
-
-    def do_recv(self, buf: ByteString):
-        """A buffer arrived, handle it."""
-        if self._cb_recv:
-            self._cb_recv(buf)
-        else:
-            # buf.hex() ; str(binascii.b2a_hex(buf)) ; buf.decode('ascii','ignore')
-            decoded: str = str(buf, encoding='ascii', errors='ignore')
-            self.value += decoded.replace("\n", "\\n").replace("\r", "\\r")
-
     def msg_custom(self,
                 widget: ipywidgets.DOMWidget,  #pylint: disable=unused-argument
                 content: Mapping[str, Any],
@@ -139,21 +128,39 @@ class SerialHubWidget(ipywidgets.DOMWidget):
         """
         self.send(content, buffers)
 
+    def on_recv(self, cb_recv: Optional[Callable[[ByteString], None]]):
+        """Set callback for received buffers of serial data"""
+        self._cb_recv = cb_recv
+
+    def do_recv(self, buf: ByteString):
+        """A buffer arrived, handle it."""
+        if self._cb_recv:
+            self._cb_recv(buf)
+        else:
+            # buf.hex() ; str(binascii.b2a_hex(buf)) ; buf.decode('ascii','ignore')
+            # decoded: str = str(buf, encoding='ascii', errors='ignore')
+            # self.value += decoded.replace("\n", "\\n").replace("\r", "\\r")
+            self.value += ascii(buf)
+
     def write_bytes(self,
-                data: ByteString
-    ) -> None:
+                    buf: ByteString
+                    ) -> None:
         """Sends a buffer for the client to write() as serial data.
-          "data" is a single bytestring to be output by client to the serialport
+          "buf" is a single bytestring to be output by client to the serialport
         """
-        self.send_custom({'type': 'SEND'}, [data])
+        self.send_custom({'type': 'SEND'}, [buf])
         (o_byt, o_pkt) = self.pkt_send_back
-        self.pkt_send_back = (o_byt + len(data), o_pkt + 1)
+        self.pkt_send_back = (o_byt + len(buf), o_pkt + 1)
+
+    def is_closed(self) -> bool:
+        """Currently presumes open if serial is supported."""
+        return not self.is_supported
 
     def write_str(self,
-                data: str,
-                enc: Optional[str] = 'ascii',
-                errs: Optional[str] = 'ignore'
-    ) -> None:
+                  data: str,
+                  enc: Optional[str] = 'ascii',
+                  errs: Optional[str] = 'ignore'
+                  ) -> None:
         """Sends a single buffer for the client to write() as serial data.
             Optional "enc" for desired encoding (default 'ascii')
             Optional "errs" for desired encoding error handling (default 'ignore')
