@@ -1,7 +1,7 @@
 // Copyright (c) cdr4eelz
 // Distributed under the terms of the Modified BSD License.
 
-  import {
+import {
   JupyterFrontEnd,
   JupyterFrontEndPlugin
 } from '@jupyterlab/application';
@@ -21,4 +21,5 @@ export default plugin;
 
 export * from './version';
 export * from './widget';
-export * from './webseriallink';
+export * from './webserialtypes';
+export * from './serialhubport';
